{ config, pkgs, lib, inputs, ... }:
let
  # Firefox Profile Setting States
  lock-false = {
    Value = false;
    Status = "locked";
  };
  lock-true = {
    Value = true;
    Status = "locked";
  };
  lock-empty-string = {
    Value = "";
    Status = "locked";
  };
in {
  home.username = "kb";
  home.homeDirectory = "/home/kb";
  home.packages = with pkgs; [
    # System
    kdePackages.kate
    kdePackages.kcalc
    # Office
    thunderbird
    libreoffice-qt6-fresh
    logseq
    kdePackages.itinerary
    ungoogled-chromium
    # Security
    gnupg
    keepassxc
    pass-wayland
    veracrypt
    protonvpn-gui
    # Media
    freetube
    inkscape
    blender
    obs-studio
    cheese
    gimp
    vlc
    kid3
    #calibre
    spotify-player
    tidal-hifi
    # Messengers
    element-desktop # Matrix Client
    signal-desktop
    deltachat-desktop
    webcord
    # Customization
    razergenie
    firefoxpwa
    # Development
    vscodium
    scrcpy
    # Experiments
    yazi # Terminal File-Manager
    # Gaming
    ryujinx # Experimental Nitendo Switch Emulator
    mangohud
    prismlauncher
    kb-one.olympus
    gnome-sudoku
    # Terminal Tools
    mosh
    btop
    fastfetch
  ];

  services.syncthing.enable = true;
  services.syncthing.extraOptions = [
    "--config=/home/kb/.config/syncthing"
    "--data=/home/kb/sync"
  ];

  services.kdeconnect.enable = true;
  services.safeeyes.enable = true;

  services.gpg-agent.enable = true;

  # SSH Configuration
  services.ssh-agent.enable = true;
  programs.ssh.enable = true;
  programs.ssh.matchBlocks."kb01@kb-one-git" = {
    host = "git.kb-one.de";
    user = "git";
    identityFile = "/home/kb/.ssh/kb01@kb-one-git";
    port = 9522;
  };
  programs.ssh.matchBlocks."kb01@0x90-git" = {
    host = "git.0x90.space";
    user = "git";
    identityFile = "/home/kb/.ssh/kb01@0x90-git";
  };
  programs.ssh.matchBlocks."master@kb-game-01" = {
    host = "kb-game-01";
    hostname = "game01.kb-one.de";
    user = "master";
    identityFile = "/home/kb/.ssh/master@kb-game-01";
    port = 3422;
  };
  programs.ssh.matchBlocks."master@kb-web-01" = {
    host = "kb-web-01";
    hostname = "kb-one.de";
    user = "master";
    identityFile = "/home/kb/.ssh/master@kb-web-01";
    port = 2222;
  };
  programs.ssh.matchBlocks."root@kb-senfnvp-remoteunlock" = {
    host = "kb-senfnvp-remoteunlock";
    hostname = "senfnvp.kb-one.de";
    user = "root";
    identityFile = "/home/kb/.ssh/root@kb-senfnvp-remoteunlock";
    port = 7299;
  };
  programs.ssh.matchBlocks."master@kb-senfnvp" = {
    host = "kb-senfnvp";
    hostname = "senfnvp.kb-one.de";
    user = "master";
    identityFile = "/home/kb/.ssh/master@kb-senfnvp";
    port = 9553;
  };
  programs.ssh.matchBlocks."master@mow0m" = {
    host = "mow0m";
    hostname = "mow0m.lan";
    user = "master";
    identityFile = "/home/kb/.ssh/master@mow0m";
    port = 9553;
  };
  programs.ssh.matchBlocks."remoteunlock-mow0m" = {
    host = "mow0m";
    hostname = "mow0m.lan";
    user = "root";
    identityFile = "/home/kb/.ssh/remoteunlock-mow0m";
    port = 2550;
  };

  programs.helix.enable = true;
  programs.helix.defaultEditor = true;

  programs.firefox = {
    enable = true;
    nativeMessagingHosts = [ pkgs.firefoxpwa ];
    policies = {
      DisableTelemetry = true;
      DisableFirefoxStudies = true;
      DisablePocket = true;
      DisableFirefoxAccounts = true;
      AutofillAddressEnabled = false;
      AutofillCreditCardEnabled = false;
      OfferToSaveLogins = false;
      FirefoxHome.TopSites = false;
      FirefoxHome.SponsoredTopSites = false;
      Preferences = {
        "browser.newtabpage.pinned" = lock-empty-string;
        "browser.topsites.contile.enabled" = lock-false;
      };
      DontCheckDefaultBrowser = true;
      DisableProfileImport = true;
      SearchBar = "unified";
      SearchEngines.Add = [ # Only Available in ESR Releases https://mozilla.github.io/policy-templates/#searchengines--add
        {
          Name = "Brave";
          URLTemplate = "https://search.brave.com/search?q={SearchTerms}";
          Alias = "br";
        }
      ];
      ExtensionSettings = { # See https://mozilla.github.io/policy-templates/#extensionsettings
        "extension@tabliss.io" = {
          install_url = "https://addons.mozilla.org/firefox/downloads/file/3940751/tabliss-2.6.0.xpi";
          installation_mode = "normal_installed";
        };
        "gdpr@cavi.au.dk" = {
          install_url = "https://addons.mozilla.org/firefox/downloads/file/4362793/consent_o_matic-1.1.3.xpi";
          installation_mode = "normal_installed";
        };
        "uBlock0@raymondhill.net" = {
          install_url = "https://addons.mozilla.org/firefox/downloads/file/4382536/ublock_origin-1.61.0.xpi";
          installation_mode = "normal_installed";
        };
        "keepassxc-browser@keepassxc.org" = {
          install_url = "https://addons.mozilla.org/firefox/downloads/file/4376326/keepassxc_browser-1.9.4.xpi";
          installation_mode = "normal_installed";
        };
        "offline-qr-code@rugk.github.io" = {
          install_url = "https://addons.mozilla.org/firefox/downloads/file/4349427/offline_qr_code_generator-1.9.xpi";
          installation_mode = "normal_installed";
        };
        "addon@darkreader.org" = {
          install_url = "https://addons.mozilla.org/firefox/downloads/file/4378073/darkreader-4.9.96.xpi";
          installation_mode = "normal_installed";
        };
        "firefoxpwa@filips.si" = {
          install_url = "https://addons.mozilla.org/firefox/downloads/file/4383345/pwas_for_firefox-2.13.1.xpi";
          installation_mode = "normal_installed";
        };
      };
      Bookmarks = [
        {
          Title = "Syncthing";
          URL = "localhost:8384";
          Placement = "toolbar";
        }
      ];
    };
  };

  home.stateVersion = "24.05";
}
