{ config, lib, pkgs, ... }:

{
  imports = [
    ./hardware.nix
  ];

  # Configure Nix
  nix.settings.experimental-features = [ "nix-command" "flakes" ];
  nix.settings.trusted-users=[ "remotebuild" ];
  nix.package = pkgs.lix;

  # Networking
  networking.hostName = "kb-senfnvp"; 
  networking.networkmanager.enable = true;
  networking.nameservers = [
    "1.1.1.1"
  ];
 
  # Set your time zone.
  time.timeZone = "Europe/Amsterdam";

  # Select internationalisation properties.
  i18n.defaultLocale = "en_US.UTF-8";
  console = {
    font = "Lat2-Terminus16";
    keyMap = "de";
  };

  users.users.master = { # Managed by Homemanager
    openssh.authorizedKeys.keys = [
      "ssh-ed25519 AAAAC3NzaC1lZDI1NTE5AAAAIJszrrdVHmMUdgOakyFNOIPV9BfopwflqivmK13Fmsab kb@Ohybke"
    ];
    isNormalUser = true;
    extraGroups = [ "wheel" ];
  };

  users.users.remotebuild = {
    isNormalUser = true;
    createHome = true;
    openssh.authorizedKeys.keys = [
      "ssh-ed25519 AAAAC3NzaC1lZDI1NTE5AAAAIJV9cwMXlbaBdg2gReSnLxH3EV5cyFoSi21f5fZhPfdC kb@Ohybke"
    ];
  };

  environment.systemPackages = with pkgs; [
    git
    wget
    vim
    tree
    fastfetch
  ];

  # Default Editor
  programs.vim.enable = true;
  programs.vim.defaultEditor = true;

  # SSH and Mosh
  services.openssh = {
    enable = true;
    settings.PasswordAuthentication = false;
    settings.KbdInteractiveAuthentication = false;
    ports = [ 9553 ];
    openFirewall = true;
  };
  programs.mosh.enable = true;

  # Open ports in the firewall.
  # networking.firewall.allowedTCPPorts = [ ... ];
  # networking.firewall.allowedUDPPorts = [ ... ];

  system.stateVersion = "24.11"; # NEVER CHANGE THIS !!!!

}

